"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from typing import Optional
from vesselapi.models import operations

class Webhooks:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    
    def create(self, request: operations.PostWebhookRequestBody) -> operations.PostWebhookResponse:
        r"""Create Webhook
        Create a new webhook for a given connection
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/connection/webhook'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostWebhookResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostWebhookResponseBody])
                res.response_body = out

        return res

    
    def delete(self, request: operations.DeleteWebhookRequestBody) -> operations.DeleteWebhookResponse:
        r"""Remove Webhook
        Removes a webhook for a given connection and id
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/connection/webhook'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        
        client = self._security_client
        
        http_res = client.request('DELETE', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteWebhookResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        

        return res

    
    def find(self, request: operations.GetOneWebhookRequest) -> operations.GetOneWebhookResponse:
        r"""Get Webhook
        Retrieve information about a webhook for a given connection and id
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/connection/webhook'
        
        query_params = utils.get_query_params(operations.GetOneWebhookRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetOneWebhookResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOneWebhookResponseBody])
                res.response_body = out

        return res

    